import 'dart:math';

import 'package:flutter/material.dart';
import 'package:hub/app_state.dart';
import 'package:hub/components/templates_components/details_component/details_component_widget.dart';
import 'package:hub/flutter_flow/flutter_flow_icon_button.dart';
import 'package:hub/flutter_flow/flutter_flow_theme.dart';
import 'package:hub/flutter_flow/flutter_flow_widgets.dart';
import 'package:hub/flutter_flow/internationalization.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:rxdart/rxdart.dart';
import 'package:share_plus/share_plus.dart';

enum status { active, unknown, canceled, finished, blocked, inactive }

status? getStatus(dynamic data) {
  debugPrint('getStatus: $data');
  switch (data) {
    case 'A':
      return status.active;
    case 'F':
      return status.finished;
    case 'B':
      return status.blocked;
    case 'C':
      return status.canceled;
    case 'I':
      return status.inactive;
    default:
      return status.unknown;
  }
}

Widget buildDetails(
    dynamic visitaWrapItem,
    BuildContext context,
    Future<dynamic> Function(BuildContext, String, String, String, String)?
        changeStatusAction) {
  return VisitRequestTemplateComponentWidget(
    vteName: 'Lorem Ipsus',
    vteReason: 'Lorem Ipsus',
    vawDate: 'Lorem Ipsus',
    vawStatus: 'Lorem Ipsus',
    vteMsg: 'Lorem Ipsus',
    vteUUID: 'Lorem Ipsus',
    cliUUID: FFAppState().cliUUID,
    msgUUID: 'Lorem Ipsus',
    vawDestino: 'Lorem Ipsus',
    vawUUID: 'Lorem Ipsus',
    vawName: 'Lorem Ipsus',
    vawRef: 'Lorem Ipsus',
    changeStatusAction: changeStatusAction,
    buttons: [
      if (getStatus(visitaWrapItem['VAW_STATUS']) ==
          status.active) // ACCEPT ACTION
        FlutterFlowIconButton(
          icon: const Icon(Icons.done),
          onPressed: () async {
            showDialog(
                context: context,
                builder: (context) {
                  return AlertDialog(
                    title: Text(
                      FFLocalizations.of(context).getVariableText(
                        ptText: 'Aprovar Visita',
                        enText: 'Approve Visit',
                      ),
                    ),
                    content: Text(
                      FFLocalizations.of(context).getVariableText(
                        ptText:
                            'Você tem certeza que deseja aprovar essa visita?',
                        enText: 'Are you sure you want to approve this visit?',
                      ),
                    ),
                    backgroundColor:
                        FlutterFlowTheme.of(context).primaryBackground,
                    actions: [
                      FFButtonWidget(
                        text: FFLocalizations.of(context).getVariableText(
                          enText: 'No',
                          ptText: 'Não',
                        ),
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        options: FFButtonOptions(
                            width: 100,
                            height: 40,
                            color:
                                FlutterFlowTheme.of(context).primaryBackground,
                            textStyle: TextStyle(
                              color: FlutterFlowTheme.of(context).primaryText,
                            ),
                            borderSide: BorderSide(
                              color: FlutterFlowTheme.of(context)
                                  .primaryBackground,
                              width: 1,
                            ),
                            borderRadius: BorderRadius.circular(10)),
                      ),
                      FFButtonWidget(
                        text: FFLocalizations.of(context).getVariableText(
                          enText: 'Yes',
                          ptText: 'Sim',
                        ),
                        onPressed: () async {
                          await changeStatusAction?.call(
                            context,
                            'L',
                            visitaWrapItem['VAW_ID'] ?? '',
                            'Mensagem',
                            visitaWrapItem['VTE_DOCUMENTO'] ?? '',
                          );
                        },
                        options: FFButtonOptions(
                          width: 100,
                          height: 40,
                          color: FlutterFlowTheme.of(context).primaryBackground,
                          textStyle: TextStyle(
                            color: FlutterFlowTheme.of(context).primaryText,
                          ),
                          borderSide: BorderSide(
                            color:
                                FlutterFlowTheme.of(context).primaryBackground,
                            width: 1,
                          ),
                          borderRadius: BorderRadius.circular(10),
                        ),
                      ),
                    ],
                  );
                });
          },
        ),
      if (getStatus(visitaWrapItem['VAW_STATUS']) ==
          status.active) // REJECT ACTION
        FlutterFlowIconButton(
          icon: const Icon(Icons.close),
          onPressed: () async {
            showDialog(
                context: context,
                builder: (context) {
                  return AlertDialog(
                    title: Text(
                      FFLocalizations.of(context).getVariableText(
                        ptText: 'Bloquear Visita',
                        enText: 'Block Visit',
                      ),
                    ),
                    content: Text(
                      FFLocalizations.of(context).getVariableText(
                        ptText:
                            'Você tem certeza que deseja bloquear essa visita?',
                        enText: 'Are you sure you want to block this visit?',
                      ),
                    ),
                    backgroundColor:
                        FlutterFlowTheme.of(context).primaryBackground,
                    actions: [
                      FFButtonWidget(
                        text: FFLocalizations.of(context).getVariableText(
                          enText: 'No',
                          ptText: 'Não',
                        ),
                        onPressed: () {
                          Navigator.pop(context);
                        },
                        options: FFButtonOptions(
                            width: 100,
                            height: 40,
                            color:
                                FlutterFlowTheme.of(context).primaryBackground,
                            textStyle: TextStyle(
                              color: FlutterFlowTheme.of(context).primaryText,
                            ),
                            borderSide: BorderSide(
                              color: FlutterFlowTheme.of(context)
                                  .primaryBackground,
                              width: 1,
                            ),
                            borderRadius: BorderRadius.circular(10)),
                      ),
                      FFButtonWidget(
                        text: FFLocalizations.of(context).getVariableText(
                          enText: 'Yes',
                          ptText: 'Sim',
                        ),
                        onPressed: () async {
                          // await changeStatusAction?.call(
                          //   context,
                          //   'B',
                          //   visitaWrapItem['VAW_REF'] ?? '',
                          //   'Mensagem',
                          //   visitaWrapItem['VTE_ID'] ?? '',
                          // );
                        },
                        options: FFButtonOptions(
                          width: 100,
                          height: 40,
                          color: FlutterFlowTheme.of(context).primaryBackground,
                          textStyle: TextStyle(
                            color: FlutterFlowTheme.of(context).primaryText,
                          ),
                          borderSide: BorderSide(
                            color:
                                FlutterFlowTheme.of(context).primaryBackground,
                            width: 1,
                          ),
                          borderRadius: BorderRadius.circular(10),
                        ),
                      ),
                    ],
                  );
                });
          },
        ),
      if (getStatus(visitaWrapItem['VAW_STATUS']) ==
          status.finished) // RECALL ACTION
        FlutterFlowIconButton(
          icon: const Icon(Icons.refresh),
          onPressed: () async {
            Navigator.pop(context);
            Navigator.pop(context);
            context.pushNamed(
              'scheduleCompleteVisitPage',
              queryParameters: {
                'visitorStrList': serializeParam(
                  visitaWrapItem['VTE_DOCUMENTO'],
                  ParamType.String,
                ),
                'visitorJsonList': serializeParam(
                  [visitaWrapItem],
                  ParamType.JSON,
                  isList: true,
                ),
              }.withoutNulls,
            );
          },
        ),
      if (getStatus(visitaWrapItem['VAW_STATUS']) ==
          status.finished) // SHARE ACTION
        FlutterFlowIconButton(
          icon: const Icon(Icons.share),
          onPressed: () async {
            Share.share('''
Olá, \*${visitaWrapItem['VTE_NOME']}\*! Você foi convidado para \*${visitaWrapItem['NAC_DESCRICAO']}\*.

\*Validade do Convite\*:
- Início: ${visitaWrapItem['VAW_DTINICIO']}
- Fim: ${visitaWrapItem['VAW_DTFIM']}

URL do Convite: https://visita.freaccess.com.br/${visitaWrapItem['VAW_ID']}/${visitaWrapItem['CLI_ID']}/${visitaWrapItem['VAW_CHAVE']}
            ''');
          },
        ),
    ],
    labelsHashMap: Map<String, String>.from({
      'Nome': visitaWrapItem['VTE_NOME'] ?? '',
      'Inicio': visitaWrapItem['VAW_DTINICIO'] ?? '',
      'Fim': visitaWrapItem['VAW_DTFIM'] ?? '',
    }),
    imageHashMap: Map<String, String>.from({
      'key': visitaWrapItem['VTE_DOCUMENTO'] ?? '',
      'value': 'E',
    }),
    statusHashMap: [
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.active)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Ativo',
            enText: 'Active',
          ): FlutterFlowTheme.of(context).warning,
        }),
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.unknown)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Pendente',
            enText: 'Pending',
          ): FlutterFlowTheme.of(context).alternate,
        }),
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.canceled)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Cancelado',
            enText: 'Canceled',
          ): FlutterFlowTheme.of(context).error,
        }),
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.finished)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Finalizado',
            enText: 'Finished',
          ): FlutterFlowTheme.of(context).success,
        }),
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.blocked)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Bloqueado',
            enText: 'Blocked',
          ): FlutterFlowTheme.of(context).error,
        }),
      if (getStatus(visitaWrapItem['VAW_STATUS']) == status.inactive)
        Map<String, Color>.from({
          FFLocalizations.of(context).getVariableText(
            ptText: 'Inativo',
            enText: 'Inactive',
          ): FlutterFlowTheme.of(context).error,
        }),
    ],
  );
}
